@@ -1,5 +1,5 @@
 /* vokoscreenNG - A desktop recorder
- * Copyright (C) 2017-2019 Volker Kohaupt
+ * Copyright (C) 2017-2022 Volker Kohaupt
  * 
  * Author:
  *      Volker Kohaupt <vkohaupt@volkoh.de>
@@ -50,7 +50,7 @@ void QvkDirectSoundController::slot_audioIconOnOff( bool state )
         QPainter painter;
         QPen pen;
         painter.begin( &workPixmap );
-        pen.setColor( Qt::red );
+        pen.setColor( QString( "#3daee9" ) );
         pen.setWidth( 2 );
         painter.setPen( pen );
         painter.drawLine ( 5, 5, size.width()-5, size.height()-5 );
