@@ -1,5 +1,5 @@
-/* vokoscreenNG - A desktop recorder
- * Copyright (C) 2017-2019 Volker Kohaupt
+﻿/* vokoscreenNG - A desktop recorder
+ * Copyright (C) 2017-2022 Volker Kohaupt
  *
  * Author:
  *      Volker Kohaupt <vkohaupt@volkoh.de>
@@ -26,6 +26,9 @@
 #include "camerasettingsdialog.h"
 
 #include <QCameraInfo>
+#include <QPainterPath>
+#include <QPaintDevice>
+#include <QBitmap>
 
 QvkCameraController::QvkCameraController( Ui_formMainWindow *ui_surface ):videoSurface(new QvkVideoSurface())
 {
@@ -38,7 +41,8 @@ QvkCameraController::QvkCameraController( Ui_formMainWindow *ui_surface ):videoS
     sliderCameraWindowSize->setMaximum( 1 );
     sliderCameraWindowSize->setValue( 0 );
     sliderCameraWindowSize->show();
-    sliderCameraWindowSize->setShowValue( true );
+    sliderCameraWindowSize->setShowValue( false );
+    sliderCameraWindowSize->setBigHandel( true );
     sliderCameraWindowSize->setEnabled( true );
 
     sliderCameraWindowZoom = new QvkSpezialSlider( Qt::Horizontal );
@@ -61,13 +65,14 @@ QvkCameraController::QvkCameraController( Ui_formMainWindow *ui_surface ):videoS
 
     QvkCameraResolution *vkCameraResolution = new QvkCameraResolution( ui_formMainWindow, vkCameraSettingsDialog );
     connect( ui_formMainWindow->comboBoxCamera, SIGNAL( currentIndexChanged( int ) ), vkCameraResolution, SLOT( slot_resolution( int ) ) );
-    connect( ui_formMainWindow->comboBoxCameraResolution, SIGNAL( currentIndexChanged( int ) ), this, SLOT( slot_resolutionChanged() ) );
+    connect( ui_formMainWindow->comboBoxCameraResolution, SIGNAL( currentIndexChanged( int ) ), this, SLOT( slot_resolutionChanged( int ) ) );
 
     getAllDevices();
 
     cameraWindow = new QvkCameraWindow( ui_surface, vkCameraSettingsDialog );
     connect( cameraWindow, SIGNAL( signal_cameraWindow_close( bool ) ), ui_formMainWindow->checkBoxCameraOnOff, SLOT( setChecked( bool ) ) );
-    cameraWindow->setWindowTitle( QString( tr( "Camera") ) );
+    cameraWindow->setWindowTitle( QString( tr( "Camera") ) + " " + global::version );
+    cameraWindow->setAttribute( Qt::WA_TranslucentBackground, true );
     QIcon icon( QString::fromUtf8( ":/pictures/logo/logo.png" ) );
     cameraWindow->setWindowIcon( icon );
 
@@ -90,10 +95,14 @@ QvkCameraController::~QvkCameraController()
 }
 
 
-void QvkCameraController::slot_resolutionChanged()
+void QvkCameraController::slot_resolutionChanged( int index )
 {
+    Q_UNUSED(index)
+    qDebug().noquote() << global::nameOutput << "[Camera] Changed resolution to: " << ui_formMainWindow->comboBoxCameraResolution->currentText();
+
+    int minimumSize = 100;
+    sliderCameraWindowSize->setMaximum( ui_formMainWindow->comboBoxCameraResolution->currentText().section( "x", 1, 1 ).toInt() - minimumSize);
     sliderCameraWindowZoom->setMaximum( ui_formMainWindow->comboBoxCameraResolution->currentText().section( "x", 1, 1 ).toInt() / 2 );
-    sliderCameraWindowSize->setMaximum( ui_formMainWindow->comboBoxCameraResolution->currentText().section( "x", 1, 1 ).toInt() );
 
     if ( ui_formMainWindow->checkBoxCameraOnOff->checkState() == Qt::Checked )
     {
@@ -150,14 +159,14 @@ void QvkCameraController::slot_frameOnOff( bool value )
 #ifdef Q_OS_WIN
         if ( value == true )
         {
-            flags = Qt::FramelessWindowHint | Qt::WindowStaysOnTopHint;
-            cameraWindow->setWindowFlags( flags );
+            cameraWindow->setWindowFlag( Qt::Window, false );
+            cameraWindow->setWindowFlag( Qt::ToolTip, true );
         }
 
         if ( value == false )
         {
-            flags = Qt::WindowStaysOnTopHint;
-            cameraWindow->setWindowFlags( flags );
+            cameraWindow->setWindowFlag( Qt::Window, true );
+            cameraWindow->setWindowFlag( Qt::ToolTip, false );
         }
 #endif
 
@@ -177,67 +186,195 @@ void QvkCameraController::slot_frameOnOff( bool value )
 
         if ( ui_formMainWindow->checkBoxCameraOnOff->isChecked() == true )
         {
-          cameraWindow->show();
+            cameraWindow->show();
         }
     }
 }
 
 
-void QvkCameraController::slot_sliderMoved( int value )
-{
-    Q_UNUSED(value)
-}
-
-
 void QvkCameraController::slot_setNewImage( QImage image )
 {
 #ifdef Q_OS_LINUX
-    if ( ui_formMainWindow->checkBoxCameraMirrorHorizontal->isChecked() == true )
+    if ( ui_formMainWindow->checkBoxCameraMirrorHorizontal->isChecked() == true ) {
         image = image.mirrored( true, false );
+    }
 
-    if ( ui_formMainWindow->checkBoxCameraMirrorVertical->isChecked() == true )
+    if ( ui_formMainWindow->checkBoxCameraMirrorVertical->isChecked() == true ) {
         image = image.mirrored( false, true );
+    }
 #endif
 
 #ifdef Q_OS_WIN
-    if ( ui_formMainWindow->checkBoxCameraMirrorHorizontal->isChecked() == true )
+    if ( ui_formMainWindow->checkBoxCameraMirrorHorizontal->isChecked() == true ) {
         image = image.mirrored( true, false );
+    }
 
-    if ( ui_formMainWindow->checkBoxCameraMirrorVertical->isChecked() == false )
+    if ( ui_formMainWindow->checkBoxCameraMirrorVertical->isChecked() == false ) {
         image = image.mirrored( false, true );
+    }
 #endif
 
-    if ( ui_formMainWindow->checkBoxCameraInvert->isChecked() == true )
+    if ( ui_formMainWindow->checkBoxCameraInvert->isChecked() == true ) {
         image.invertPixels( QImage::InvertRgb );
+    }
 
-    if ( ui_formMainWindow->checkBoxCameraGray->isChecked() == true )
+    if ( ui_formMainWindow->checkBoxCameraGray->isChecked() == true ) {
         image = image.convertToFormat( QImage::Format_Grayscale8 );
+    }
 
-    if ( ui_formMainWindow->checkBoxCameraMono->isChecked() == true )
+    if ( ui_formMainWindow->checkBoxCameraMono->isChecked() == true ) {
         image = image.convertToFormat( QImage::Format_Mono );
+    }
+
 
     // Zoom
-    qreal width = image.width();
-    qreal height = image.height();
-    qreal quotient = width / height;
-    int minusPixel = sliderCameraWindowZoom->value();
-    QImage image_zoom = image.copy( minusPixel,
-                                    minusPixel / quotient,
-                                    width - ( 2 * minusPixel ),
-                                    height - ( 2 * minusPixel / quotient )
-                                    );
-    image = image_zoom.scaled( cameraWindow->width(), cameraWindow->height(), Qt::KeepAspectRatio, Qt::SmoothTransformation );
-    cameraWindow->setPixmap( QPixmap::fromImage( image, Qt::AutoColor ) );
+    if ( sliderCameraWindowZoom->value() > 0 )
+    {
+        qreal width = image.width();
+        qreal height = image.height();
+        qreal quotient = width / height;
+        qreal minusPixel = sliderCameraWindowZoom->value();
+        QImage image_zoom = image.copy( minusPixel,
+                                        minusPixel / quotient,
+                                        width - ( 2 * minusPixel ),
+                                        height - ( 2 * minusPixel / quotient )
+                                        );
+        image = image_zoom.scaled( width, height, Qt::IgnoreAspectRatio, Qt::SmoothTransformation );
+    }
     // Zoom end
 
-    // Window size
-    if ( cameraWindow->isFullScreen() == false )
+
+    // Rectangel
+    if ( ui_formMainWindow->toolButton_camera_view_rectangle->isChecked() == true )
     {
-        cameraWindow->setFixedSize( ui_formMainWindow->comboBoxCameraResolution->currentText().section( "x", 0, 0 ).toInt() - sliderCameraWindowSize->value(),
-                                    ui_formMainWindow->comboBoxCameraResolution->currentText().section( "x", 1, 1 ).toInt() - ( sliderCameraWindowSize->value() / quotient )
-                                    );
+        if ( cameraWindow->isFullScreen() == false )
+        {
+            qreal width = image.width();
+            qreal height = image.height();
+            qreal quotient = width / height;
+            int w = ui_formMainWindow->comboBoxCameraResolution->currentText().section( "x", 0, 0 ).toInt() - sliderCameraWindowSize->value();
+            int h = ui_formMainWindow->comboBoxCameraResolution->currentText().section( "x", 1, 1 ).toInt() - sliderCameraWindowSize->value() / quotient;
+            image = image.scaled( w, h, Qt::IgnoreAspectRatio, Qt::SmoothTransformation );
+            cameraWindow->setFixedSize( image.width(), image.height() );
+            cameraWindow->setNewImage( image );
+            return;
+        } else {
+            cameraWindow->setNewImage( image );
+            return;
+        }
     }
-    // Window size end
+    // Rectangel end
+
+
+    // Ellipse
+    if ( ui_formMainWindow->toolButton_camera_view_ellipse->isChecked() == true )
+    {
+        if ( cameraWindow->isFullScreen() == false ) {
+            qreal width = image.width();
+            qreal height = image.height();
+            qreal quotient = width / height;
+            int w = ui_formMainWindow->comboBoxCameraResolution->currentText().section( "x", 0, 0 ).toInt() - sliderCameraWindowSize->value();
+            int h = ui_formMainWindow->comboBoxCameraResolution->currentText().section( "x", 1, 1 ).toInt() - sliderCameraWindowSize->value() / quotient;
+            image = image.scaled( w, h, Qt::KeepAspectRatio, Qt::SmoothTransformation );
+        }
+        QPixmap pixmap( image.width(), image.height() );
+        pixmap.fill( Qt::transparent );
+        QPainter painter;
+        painter.begin( &pixmap );
+        painter.setRenderHints( QPainter::Antialiasing, true );
+        QPainterPath path;
+        path.addEllipse( 0, 0, image.width(), image.height() );
+        painter.setClipPath( path );
+        painter.drawImage( QPoint( 0, 0 ), image );
+        painter.end();
+        image = pixmap.toImage();
+        if ( cameraWindow->isFullScreen() == false ) {
+            cameraWindow->setFixedSize( image.width(), image.height() );
+        }
+    }
+
+
+    // Circle
+    if ( ui_formMainWindow->toolButton_camera_view_circle->isChecked() == true )
+    {
+        if ( cameraWindow->isFullScreen() == true ){
+            int w = image.width();
+            int h = image.height();
+            QPixmap pixmap( w, h );
+            pixmap.fill( Qt::transparent );
+            QPainter painter;
+            painter.begin( &pixmap );
+            painter.setRenderHints( QPainter::Antialiasing, true );
+            QPainterPath path;
+            path.addEllipse( (w-h)/2, 0, h, h );
+            painter.setClipPath( path );
+            image = image.scaled( w, h, Qt::KeepAspectRatio, Qt::SmoothTransformation );
+            painter.drawImage( 0, 0, image );
+            painter.end();
+            image = pixmap.toImage();
+        } else {   
+#ifdef Q_OS_LINUX
+            // Under linux absolute perfect. Under Windows outer black line.
+            qreal width = image.width();
+            qreal height = image.height();
+            qreal quotient = width / height;
+            qreal w = ui_formMainWindow->comboBoxCameraResolution->currentText().section( "x", 0, 0 ).toInt() - sliderCameraWindowSize->value();
+            qreal h = ui_formMainWindow->comboBoxCameraResolution->currentText().section( "x", 1, 1 ).toInt() - sliderCameraWindowSize->value() / quotient;
+
+            QPixmap pixmap( h, h );
+            pixmap.fill( Qt::transparent );
+            QPainter painter;
+            painter.begin( &pixmap );
+            painter.setRenderHints( QPainter::Antialiasing, true );
+            painter.setRenderHint( QPainter::SmoothPixmapTransform, true );
+
+            QPainterPath path;
+            path.addEllipse( 0, 0, h, h );
+            painter.setClipPath( path );
+
+            QRectF target( 0.0, 0.0, h, h );
+            QRectF source( (w-h)/2, 0.0, image.height(), image.height() );
+            painter.drawImage( target, image, source );
+
+            painter.end();
+
+            image = pixmap.toImage();
+
+            cameraWindow->setFixedSize( h, h );
+#endif
+            // Under Windows a bit better as the other code
+#ifdef Q_OS_WIN
+            qreal width = image.width();
+            qreal height = image.height();
+            qreal quotient = width / height;
+            qreal w = ui_formMainWindow->comboBoxCameraResolution->currentText().section( "x", 0, 0 ).toInt() - sliderCameraWindowSize->value();
+            qreal h = ui_formMainWindow->comboBoxCameraResolution->currentText().section( "x", 1, 1 ).toInt() - sliderCameraWindowSize->value() / quotient;
+
+            QPixmap pixmap( h, h );
+            pixmap.fill( Qt::transparent );
+            QPainter painter;
+            painter.begin( &pixmap );
+            painter.setRenderHint( QPainter::Antialiasing, true );
+            painter.setRenderHint( QPainter::SmoothPixmapTransform, true );
+
+            QRegion region( QRect( 0, 0, h, h ), QRegion::Ellipse );
+            painter.setClipRegion( region );
+            painter.drawImage( QPointF( 0.0, 0.0 ), image );
+
+            QRectF target( 0.0, 0.0, h, h );
+            QRectF source( (w-h)/2, 0.0, image.height(), image.height() );
+            painter.drawImage( target, image, source );
+            painter.end();
+
+            image = pixmap.toImage();
+
+            cameraWindow->setFixedSize( h, h );
+#endif
+        }
+    }
+    // Circle end
+
+    cameraWindow->setNewImage( image );
 }
 
 
@@ -372,9 +509,8 @@ void QvkCameraController::slot_error( QCamera::Error error )
     case QCamera::CameraError:
     {
         qDebug().noquote() << global::nameOutput << "General Camera error";
-        cameraWindow->clear();
-        cameraWindow->setStyleSheet( "background-color:white;" );
-        cameraWindow->setText( "Camera is busy " );
+        cameraWindow->error = "Camera is busy";
+        cameraWindow->repaint();
         break;
     }
     case QCamera::InvalidRequestError:
