@@ -1,5 +1,5 @@
 /* vokoscreenNG
- * Copyright (C) 2017-2021 Volker Kohaupt
+ * Copyright (C) 2017-2022 Volker Kohaupt
  *
  * Author:
  *      Volker Kohaupt <vkohaupt@volkoh.de>
@@ -39,12 +39,17 @@ void QvkHalo::init( Ui_formMainWindow *ui_formMainWindow )
     ui = ui_formMainWindow;
 
     createHaloPreviewWidget();
-    createHaloWindow();
+    vkHaloWindow = new QvkHaloWindow( this );
     createSpezialSlider();
     createColorButtons();
     createSpezialCheckBox();
 
     setToolButtonDefaultValues();
+
+    timer = new QTimer( this );
+    timer->setTimerType( Qt::PreciseTimer );
+    timer->setInterval( 40 );
+    connect( timer, SIGNAL( timeout() ), this, SLOT( slot_mytimer() ) );
 }
 
 
@@ -57,13 +62,6 @@ void QvkHalo::createHaloPreviewWidget()
 }
 
 
-void QvkHalo::createHaloWindow()
-{
-    vkHaloWindow = new QvkHaloWindow( this );
-    vkHaloWindow->setWindowFlags( Qt::FramelessWindowHint | Qt::WindowStaysOnTopHint | Qt::ToolTip ); //With tooltip, no entry in Taskbar
-}
-
-
 void QvkHalo::createSpezialSlider()
 {
     vkSpezialSliderHole = new QvkSpezialSlider( Qt::Horizontal );
@@ -75,6 +73,7 @@ void QvkHalo::createSpezialSlider()
     vkSpezialSliderHole->setValue( 30 ); // This value must be greater than the holeDefault in order to be changed after the connect
     vkSpezialSliderHole->setShowValue( false );
     vkSpezialSliderHole->show();
+    vkSpezialSliderHole->setBigHandel( false);
     connect( vkSpezialSliderHole, SIGNAL( valueChanged( int ) ), this, SLOT( slot_valueChanged_SpezialSlider_Hole( int ) ) );
     vkSpezialSliderHole->setValue( holeDefault );
 
@@ -87,6 +86,7 @@ void QvkHalo::createSpezialSlider()
     vkSpezialSliderDiameter->setValue( 0 );
     vkSpezialSliderDiameter->setShowValue( false );
     vkSpezialSliderDiameter->show();
+    vkSpezialSliderDiameter->setBigHandel( false );
     connect( vkSpezialSliderDiameter, SIGNAL( valueChanged( int ) ), this, SLOT( slot_valueChanged_SpezialSlider_Diameter( int ) ) );
     vkSpezialSliderDiameter->setValue( diameterDefault );
 
@@ -99,6 +99,7 @@ void QvkHalo::createSpezialSlider()
     vkSpezialSliderOpacity->setValue( 0 );
     vkSpezialSliderOpacity->setShowValue( false );
     vkSpezialSliderOpacity->show();
+    vkSpezialSliderOpacity->setBigHandel( false );
     connect( vkSpezialSliderOpacity, SIGNAL( valueChanged( int ) ), this, SLOT( slot_valueChanged_SpezialSlider_Opacity( int ) ) );
     vkSpezialSliderOpacity->setValue( opacityDefault );
 }
@@ -110,7 +111,6 @@ void QvkHalo::slot_valueChanged_SpezialSlider_Diameter( int value )
     vkHaloWindow->setDiameter( value );
 
     vkSpezialSliderHole->setMaximum( vkSpezialSliderDiameter->value()/2  );
-
 }
 
 
@@ -167,31 +167,37 @@ void QvkHalo::slot_haloOnOff( bool value )
 {
     if ( value == true )
     {
-        timerID = startTimer( 10, Qt::PreciseTimer );
+        timer->start();
         vkHaloWindow->show();
     }
 
     if ( value == false )
     {
-        killTimer( timerID );
+        timer->stop();
         vkHaloWindow->hide();
     }
 }
 
 
-/*
- * Move the halo window and brings the window on the top
- */
-void QvkHalo::timerEvent( QTimerEvent *event )
+void QvkHalo::slot_mytimer()
 {
-    Q_UNUSED(event);
-
     if ( global::showclickCounter == 0 )
     {
         vkHaloWindow->raise();
     }
 
-    vkHaloWindow->move( QCursor::pos().x() - vkHaloWindow->diameter/2, QCursor::pos().y() - vkHaloWindow->diameter/2 );
+    if ( QCursor::pos() != oldPos )
+    {
+        vkHaloWindow->repaint();
+
+        vkHaloWindow->resize( vkHaloWindow->screen->size().width(),
+                              vkHaloWindow->screen->size().height() );
+
+        vkHaloWindow->move( vkHaloWindow->screen->geometry().x(),
+                            vkHaloWindow->screen->geometry().y() );
+
+        oldPos = QCursor::pos();
+    }
 }
 
 
