@@ -1,5 +1,5 @@
 /* vokoscreenNG
- * Copyright (C) 2017-2021 Volker Kohaupt
+ * Copyright (C) 2017-2022 Volker Kohaupt
  *
  * Author:
  *      Volker Kohaupt <vkohaupt@volkoh.de>
@@ -24,6 +24,7 @@
 #define QVKHALO_H
 
 #include <QWidget>
+#include <QTimer>
 
 #include "QvkSpezialSlider.h"
 #include "QvkHaloPreviewWidget.h"
@@ -59,27 +60,25 @@ private:
     int diameterDefault = 70;
     int opacityDefault = 60;
     int holeDefault = 5;
-    int timerID;
+    QTimer *timer;
+    QPoint oldPos = QPoint( -1, -1 );
 
-    void createHaloWindow();
     void createHaloPreviewWidget();
     void createSpezialSlider();
     void createColorButtons();
     void createSpezialCheckBox();
-
     void setToolButtonDefaultValues();
 
 
-
 private slots:
     void slot_valueChanged_SpezialSlider_Diameter( int value );
     void slot_valueChanged_SpezialSlider_Opacity( int value );
     void slot_valueChanged_SpezialSlider_Hole( int value );
     void slot_haloOnOff( bool value );
+    void slot_mytimer();
 
 
 protected:
-    void timerEvent(QTimerEvent *event) override;
 
 
 };
