@@ -103,6 +103,7 @@
     </message>
     <message>
         <source>No filemanager found.</source>
+        <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
         <translation>No s’ha trobat cap gestor de fitxers.</translation>
     </message>
     <message>
@@ -147,6 +148,17 @@
         <translation>Àrea</translation>
     </message>
 </context>
+<context>
+    <name>QvkSnapshot</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>No s’ha trobat cap gestor de fitxers.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Instal·leu un gestor de fitxers.</translation>
+    </message>
+</context>
 <context>
     <name>QvkSystray</name>
     <message>
@@ -406,10 +418,6 @@
         <source>Gray</source>
         <translation>Gris</translation>
     </message>
-    <message>
-        <source>Send Report</source>
-        <translation>Envia el registre</translation>
-    </message>
     <message>
         <source>CTRL+SHIFT+F10</source>
         <translation>Ctrl+Majús.+F10</translation>
@@ -522,6 +530,22 @@
         <source>If it shows assigned but does not work, it is being used by another program.</source>
         <translation>Si es mostra com assignada, però no funciona, es deu a que és emprada per un altre programa.</translation>
     </message>
+    <message>
+        <source>Snapshot</source>
+        <translation>Instantània</translation>
+    </message>
+    <message>
+        <source>Imagepath</source>
+        <translation>Camí de la imatge</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>Oculta aquesta finestra</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>Segons d&apos;espera abans de l&apos;enregistrament</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
