@@ -32,7 +32,7 @@
     </message>
     <message>
         <source>Close this window and start vokoscreenNG again.</source>
-        <translation>Zavřít toto okno a znovu spustit vokoscreenNG.</translation>
+        <translation>Zavřít toto okno, a spustit vokoscreenNG znovu.</translation>
     </message>
     <message>
         <source>Have fun with vokoscreenNG</source>
@@ -103,6 +103,7 @@
     </message>
     <message>
         <source>No filemanager found.</source>
+        <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
         <translation>Nebyl nalezen žádný správce souborů.</translation>
     </message>
     <message>
@@ -147,6 +148,17 @@
         <translation>Výřez</translation>
     </message>
 </context>
+<context>
+    <name>QvkSnapshot</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Nebyl nalezen žádný správce souborů.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Prosím o instalaci správce souborů.</translation>
+    </message>
+</context>
 <context>
     <name>QvkSystray</name>
     <message>
@@ -406,10 +418,6 @@
         <source>Gray</source>
         <translation>Šedý</translation>
     </message>
-    <message>
-        <source>Send Report</source>
-        <translation>Zaslat report</translation>
-    </message>
     <message>
         <source>CTRL+SHIFT+F10</source>
         <translation>CTRL+SHIFT+F10</translation>
@@ -522,6 +530,25 @@
         <source>If it shows assigned but does not work, it is being used by another program.</source>
         <translation>Pokud je zobrazena jako přiřazená, ale nefunguje, používá ji jiný program.</translation>
     </message>
+    <message>
+        <source>Snapshot</source>
+        <translation>Momentka</translation>
+    </message>
+    <message>
+        <source>Imagepath</source>
+        <translation>Složka nahrávek (záznamů)</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>Skrýt toto okno</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>Vteřin počkej před nahráváním  - The best by me.
+Vteřin počkat před nahráváním??
+Sekund počkej před natáčením??
+Sekund počkej před záznamem??</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
