@@ -103,6 +103,7 @@
     </message>
     <message>
         <source>No filemanager found.</source>
+        <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
         <translation>Kein Dateimanager gefunden</translation>
     </message>
     <message>
@@ -147,6 +148,17 @@
         <translation>Bereich</translation>
     </message>
 </context>
+<context>
+    <name>QvkSnapshot</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Kein Dateimanager gefunden</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Bitte installiere einen Dateimanager</translation>
+    </message>
+</context>
 <context>
     <name>QvkSystray</name>
     <message>
@@ -406,10 +418,6 @@
         <source>Gray</source>
         <translation>grau</translation>
     </message>
-    <message>
-        <source>Send Report</source>
-        <translation>Sende Report</translation>
-    </message>
     <message>
         <source>CTRL+SHIFT+F10</source>
         <translation>CTRL+SHIFT+F10</translation>
@@ -522,6 +530,22 @@
         <source>If it shows assigned but does not work, it is being used by another program.</source>
         <translation>Wenn es zugewiesen anzeigt, aber nicht funktioniert, wird es von einem anderen Programm verwendet.</translation>
     </message>
+    <message>
+        <source>Snapshot</source>
+        <translation>Snapshot</translation>
+    </message>
+    <message>
+        <source>Imagepath</source>
+        <translation>Bilderpfad</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>Dieses Fenster ausblenden</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>Sekunden warten, bevor die Aufnahme beginnt</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
