@@ -104,6 +104,7 @@
     </message>
     <message>
         <source>No filemanager found.</source>
+        <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
         <translation>No se encontró ningún gestor de archivos.</translation>
     </message>
     <message>
@@ -148,6 +149,17 @@
         <translation>Área</translation>
     </message>
 </context>
+<context>
+    <name>QvkSnapshot</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>No se encontró ningún gestor de archivos.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Instale un gestor de archivos.</translation>
+    </message>
+</context>
 <context>
     <name>QvkSystray</name>
     <message>
@@ -408,10 +420,6 @@
         <source>Gray</source>
         <translation>Gris</translation>
     </message>
-    <message>
-        <source>Send Report</source>
-        <translation>Enviar informe</translation>
-    </message>
     <message>
         <source>CTRL+SHIFT+F10</source>
         <translation>Ctrl + Mayús + F10</translation>
@@ -524,6 +532,22 @@
         <source>If it shows assigned but does not work, it is being used by another program.</source>
         <translation>Si aparece asignado pero no funciona, es que está siendo utilizado por otro programa</translation>
     </message>
+    <message>
+        <source>Snapshot</source>
+        <translation>Captura</translation>
+    </message>
+    <message>
+        <source>Imagepath</source>
+        <translation>Ruta de la imagen</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>Ocultar esta ventana</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>Segundos en espera antes de grabar</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
