@@ -103,6 +103,7 @@
     </message>
     <message>
         <source>No filemanager found.</source>
+        <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
         <translation>Ez da fitxategi arakatzailerik aurkitu</translation>
     </message>
     <message>
@@ -147,6 +148,17 @@
         <translation>Eremua</translation>
     </message>
 </context>
+<context>
+    <name>QvkSnapshot</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Ez da fitxategi-arakatzailerik aurkitu</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Instalatu fitxategi-arakatzaile bat.</translation>
+    </message>
+</context>
 <context>
     <name>QvkSystray</name>
     <message>
@@ -406,10 +418,6 @@
         <source>Gray</source>
         <translation>Grisa</translation>
     </message>
-    <message>
-        <source>Send Report</source>
-        <translation>Bidali txostena</translation>
-    </message>
     <message>
         <source>CTRL+SHIFT+F10</source>
         <translation>CTRL+MAIUS+F10</translation>
@@ -522,6 +530,22 @@
         <source>If it shows assigned but does not work, it is being used by another program.</source>
         <translation>Esleituta agertzen bada baina ez badabil, beste programa batek erabiltzen du.</translation>
     </message>
+    <message>
+        <source>Snapshot</source>
+        <translation>Pantaila argazkia</translation>
+    </message>
+    <message>
+        <source>Imagepath</source>
+        <translation>Irudi-bidea</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>Ezkutatu leiho hau</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>Segundo hauen ondoren hasi grabatzen</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
