@@ -103,6 +103,7 @@
     </message>
     <message>
         <source>No filemanager found.</source>
+        <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
         <translation>Tiedostonhallintaa ei löytynyt.</translation>
     </message>
     <message>
@@ -147,6 +148,17 @@
         <translation>Alue</translation>
     </message>
 </context>
+<context>
+    <name>QvkSnapshot</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Tiedostonhallintaa ei löytynyt.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Asenna tiedostonhallinta. </translation>
+    </message>
+</context>
 <context>
     <name>QvkSystray</name>
     <message>
@@ -406,10 +418,6 @@
         <source>Gray</source>
         <translation>Harmaa</translation>
     </message>
-    <message>
-        <source>Send Report</source>
-        <translation>Lähetä raportti</translation>
-    </message>
     <message>
         <source>CTRL+SHIFT+F10</source>
         <translation>CTRL+SHIFT+F10</translation>
@@ -522,6 +530,22 @@
         <source>If it shows assigned but does not work, it is being used by another program.</source>
         <translation>Jos näyttää määritystä, mutta ei toimi, se on toisen ohjelman käytössä.</translation>
     </message>
+    <message>
+        <source>Snapshot</source>
+        <translation>Valokuva</translation>
+    </message>
+    <message>
+        <source>Imagepath</source>
+        <translation>Kuvan polku</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>Piilota tämä ikkuna</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>Odotusaika ennen tallennusta</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
