@@ -3,7 +3,7 @@
     <name>QvkAudioController</name>
     <message>
         <source>Select one or more devices</source>
-        <translation>Sélectionnez un ou plusieurs fichiers</translation>
+        <translation>Sélectionnez un ou plusieurs appareils</translation>
     </message>
 </context>
 <context>
@@ -17,7 +17,7 @@
     <name>QvkCameraWindow</name>
     <message>
         <source>Switch to Window</source>
-        <translation>Basculez vers la fenêtre</translation>
+        <translation>Mode fenêtré</translation>
     </message>
     <message>
         <source>Switch to Fullscreen</source>
@@ -68,7 +68,7 @@
     <name>QvkLimitDiskFreeSpace</name>
     <message>
         <source>Warning</source>
-        <translation>Attention, danger !</translation>
+        <translation>Attention</translation>
     </message>
     <message>
         <source>The recording is not started, not enough free disk space.</source>
@@ -103,6 +103,7 @@
     </message>
     <message>
         <source>No filemanager found.</source>
+        <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
         <translation>Aucun gestionnaire de fichiers trouvé.</translation>
     </message>
     <message>
@@ -147,6 +148,17 @@
         <translation>Définir une zone manuellement</translation>
     </message>
 </context>
+<context>
+    <name>QvkSnapshot</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Aucun gestionnaire de fichiers trouvé.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Veuillez installer un gestionnaire de fichiers.</translation>
+    </message>
+</context>
 <context>
     <name>QvkSystray</name>
     <message>
@@ -406,10 +418,6 @@
         <source>Gray</source>
         <translation>Gris</translation>
     </message>
-    <message>
-        <source>Send Report</source>
-        <translation>Envoyer un Rapport</translation>
-    </message>
     <message>
         <source>CTRL+SHIFT+F10</source>
         <translation>CTRL+SHIFT+F10</translation>
@@ -522,6 +530,22 @@
         <source>If it shows assigned but does not work, it is being used by another program.</source>
         <translation>Si marqué comme assigné mais que cela ne fonctionne pas, il doit être utilisé par un autre programme.</translation>
     </message>
+    <message>
+        <source>Snapshot</source>
+        <translation>Instantané</translation>
+    </message>
+    <message>
+        <source>Imagepath</source>
+        <translation>Chemin de l&apos;image</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>Masquer cette fenêtre</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>Secondes d&apos;attente avant l&apos;enregistrement</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
