@@ -103,6 +103,7 @@
     </message>
     <message>
         <source>No filemanager found.</source>
+        <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
         <translation>Filemanager non trovato.</translation>
     </message>
     <message>
@@ -147,6 +148,17 @@
         <translation>Area</translation>
     </message>
 </context>
+<context>
+    <name>QvkSnapshot</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Filemanager non trovato.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Si prega di installare un filemanager.</translation>
+    </message>
+</context>
 <context>
     <name>QvkSystray</name>
     <message>
@@ -406,10 +418,6 @@
         <source>Gray</source>
         <translation>Grigio</translation>
     </message>
-    <message>
-        <source>Send Report</source>
-        <translation>Invia segnalazione</translation>
-    </message>
     <message>
         <source>CTRL+SHIFT+F10</source>
         <translation>CTRL+SHIFT+F10</translation>
@@ -522,6 +530,22 @@
         <source>If it shows assigned but does not work, it is being used by another program.</source>
         <translation>Se mostra l&apos;assegnamento ma non funziona, significa che è usata da qualche altro programma.</translation>
     </message>
+    <message>
+        <source>Snapshot</source>
+        <translation>Snapshot</translation>
+    </message>
+    <message>
+        <source>Imagepath</source>
+        <translation>Percorso immagine</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>Nascondi questa finestra</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>Secondi di attesa prima di registrare</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
