@@ -103,6 +103,7 @@
     </message>
     <message>
         <source>No filemanager found.</source>
+        <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
         <translation>Nerasta jokios failų tvarkytuvės.</translation>
     </message>
     <message>
@@ -147,6 +148,17 @@
         <translation>Sritis</translation>
     </message>
 </context>
+<context>
+    <name>QvkSnapshot</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Nerasta jokios failų tvarkytuvės.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Įdiekite failų tvarkytuvę.</translation>
+    </message>
+</context>
 <context>
     <name>QvkSystray</name>
     <message>
@@ -406,10 +418,6 @@
         <source>Gray</source>
         <translation>Pilka</translation>
     </message>
-    <message>
-        <source>Send Report</source>
-        <translation>Siųsti ataskaitą</translation>
-    </message>
     <message>
         <source>CTRL+SHIFT+F10</source>
         <translation>VALD+LYG2+F10</translation>
@@ -522,6 +530,22 @@
         <source>If it shows assigned but does not work, it is being used by another program.</source>
         <translation>Jei yra rodoma, jog jis yra priskirtas, o jis neveikia, vadinasi jį naudoja kita programa.</translation>
     </message>
+    <message>
+        <source>Snapshot</source>
+        <translation>Momentinė kopija</translation>
+    </message>
+    <message>
+        <source>Imagepath</source>
+        <translation>Paveikslo kelias</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>Slėpti šį langą</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>Kiek sekundžių laukti, prieš įrašinėjant</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
