@@ -103,6 +103,7 @@
     </message>
     <message>
         <source>No filemanager found.</source>
+        <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
         <translation>Er is geen bestandsbeheerder aangetroffen.</translation>
     </message>
     <message>
@@ -147,6 +148,17 @@
         <translation>Gebied</translation>
     </message>
 </context>
+<context>
+    <name>QvkSnapshot</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Er is geen bestandsbeheerder aangetroffen.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Installeer een bestandsbeheerder.</translation>
+    </message>
+</context>
 <context>
     <name>QvkSystray</name>
     <message>
@@ -406,10 +418,6 @@
         <source>Gray</source>
         <translation>Grijs</translation>
     </message>
-    <message>
-        <source>Send Report</source>
-        <translation>Rapportage versturen</translation>
-    </message>
     <message>
         <source>CTRL+SHIFT+F10</source>
         <translation>CTRL+SHIFT+F10</translation>
@@ -522,6 +530,22 @@
         <source>If it shows assigned but does not work, it is being used by another program.</source>
         <translation>Als de sneltoets wordt aangeduid als toegewezen maar niet werkt, dan is de sneltoets reeds in gebruik door een ander programma.</translation>
     </message>
+    <message>
+        <source>Snapshot</source>
+        <translation>Schermfoto</translation>
+    </message>
+    <message>
+        <source>Imagepath</source>
+        <translation>Afbeeldingslocatie</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>Venster verbergen</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>Aantal seconden voordat opname start</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
