@@ -21,7 +21,7 @@
     </message>
     <message>
         <source>Switch to Fullscreen</source>
-        <translation>Mudar para o Modo Tela Cheia</translation>
+        <translation>Alternar para Tela Cheia</translation>
     </message>
 </context>
 <context>
@@ -103,6 +103,7 @@
     </message>
     <message>
         <source>No filemanager found.</source>
+        <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
         <translation>Nenhum gerenciador de arquivos encontrado.</translation>
     </message>
     <message>
@@ -147,6 +148,17 @@
         <translation>Área</translation>
     </message>
 </context>
+<context>
+    <name>QvkSnapshot</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Nenhum gerenciador de arquivos encontrado.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Por favor instale um gerenciador de arquivos.</translation>
+    </message>
+</context>
 <context>
     <name>QvkSystray</name>
     <message>
@@ -406,10 +418,6 @@
         <source>Gray</source>
         <translation>Cinzento</translation>
     </message>
-    <message>
-        <source>Send Report</source>
-        <translation>Enviar relatório</translation>
-    </message>
     <message>
         <source>CTRL+SHIFT+F10</source>
         <translation>CTRL+SHIFT+F10</translation>
@@ -522,6 +530,22 @@
         <source>If it shows assigned but does not work, it is being used by another program.</source>
         <translation>Se o atalho foi atribuído, mas não funciona, ele pode estar sendo utilizado por outro programa.</translation>
     </message>
+    <message>
+        <source>Snapshot</source>
+        <translation>Captura instantânea</translation>
+    </message>
+    <message>
+        <source>Imagepath</source>
+        <translation>Diretório da imagem</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>Ocultar esta janela</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>Aguarde segundos antes de gravar</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
