@@ -103,7 +103,8 @@
     </message>
     <message>
         <source>No filemanager found.</source>
-        <translation>Файловый менеджер не найден.</translation>
+        <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
+        <translation>Файловый менеджер не найден</translation>
     </message>
     <message>
         <source>Please install a filemanager.</source>
@@ -147,6 +148,17 @@
         <translation>Область экрана</translation>
     </message>
 </context>
+<context>
+    <name>QvkSnapshot</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Файловый менеджер не найден.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Пожалуйста установите файловый менеджер.</translation>
+    </message>
+</context>
 <context>
     <name>QvkSystray</name>
     <message>
@@ -406,10 +418,6 @@
         <source>Gray</source>
         <translation>Чёрно-белое в оттенках серого</translation>
     </message>
-    <message>
-        <source>Send Report</source>
-        <translation>Отправить сообщение об ошибке</translation>
-    </message>
     <message>
         <source>CTRL+SHIFT+F10</source>
         <translation>CTRL+SHIFT+F10</translation>
@@ -522,6 +530,22 @@
         <source>If it shows assigned but does not work, it is being used by another program.</source>
         <translation>Отображение фактически не работающей комбинации клавиш в качестве использующейся означает, что она используется другой программой</translation>
     </message>
+    <message>
+        <source>Snapshot</source>
+        <translation>Снимок</translation>
+    </message>
+    <message>
+        <source>Imagepath</source>
+        <translation>Путь изображения</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>Скрыть это окно</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>Секунды ожидания перед записью</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
