@@ -103,6 +103,7 @@
     </message>
     <message>
         <source>No filemanager found.</source>
+        <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
         <translation>Ingen filhanterare hittades.</translation>
     </message>
     <message>
@@ -147,6 +148,17 @@
         <translation>Område</translation>
     </message>
 </context>
+<context>
+    <name>QvkSnapshot</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Ingen filhanterare hittades.</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Installera en filhanterare.</translation>
+    </message>
+</context>
 <context>
     <name>QvkSystray</name>
     <message>
@@ -406,10 +418,6 @@
         <source>Gray</source>
         <translation>Grå</translation>
     </message>
-    <message>
-        <source>Send Report</source>
-        <translation>Skicka rapport</translation>
-    </message>
     <message>
         <source>CTRL+SHIFT+F10</source>
         <translation>CTRL+SHIFT+F10</translation>
@@ -522,6 +530,22 @@
         <source>If it shows assigned but does not work, it is being used by another program.</source>
         <translation>Om den visas som tilldelad men inte fungerar, används den av ett annat program.</translation>
     </message>
+    <message>
+        <source>Snapshot</source>
+        <translation>Ögonblicksbild</translation>
+    </message>
+    <message>
+        <source>Imagepath</source>
+        <translation>Bildsökväg</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>Dölj det här fönstret</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>Sekunders väntetid före inspelning</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
