@@ -103,6 +103,7 @@
     </message>
     <message>
         <source>No filemanager found.</source>
+        <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
         <translation>Dosya yöneticisi bulunamadı</translation>
     </message>
     <message>
@@ -147,6 +148,17 @@
         <translation>Bölge</translation>
     </message>
 </context>
+<context>
+    <name>QvkSnapshot</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>Dosya yöneticisi bulunamadı</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>Lütfen bir dosya yöneticisi yükleyin.</translation>
+    </message>
+</context>
 <context>
     <name>QvkSystray</name>
     <message>
@@ -284,7 +296,7 @@
     </message>
     <message>
         <source>Frames</source>
-        <translation>Çerçeveler</translation>
+        <translation>Kare sayısı</translation>
     </message>
     <message>
         <source>Videocodec</source>
@@ -406,10 +418,6 @@
         <source>Gray</source>
         <translation>Gri</translation>
     </message>
-    <message>
-        <source>Send Report</source>
-        <translation>Rapor Gönder</translation>
-    </message>
     <message>
         <source>CTRL+SHIFT+F10</source>
         <translation>CTRL+SHIFT+F10</translation>
@@ -440,7 +448,7 @@
     </message>
     <message>
         <source>Starts minimized</source>
-        <translation>Küçültülmüş başlat</translation>
+        <translation>Simge durumunda başlat</translation>
     </message>
     <message>
         <source>Flip horizontal</source>
@@ -516,12 +524,28 @@
     </message>
     <message>
         <source>Keyboard shortcut not assigned or assigned more than once.</source>
-        <translation>Klavye kısayolu birden fazla atanmamış veya atanmamış.</translation>
+        <translation>Klavye kısayolu atanmamış veya birden fazla atanmış.</translation>
     </message>
     <message>
         <source>If it shows assigned but does not work, it is being used by another program.</source>
         <translation>Atanmış görünüyor ancak çalışmıyorsa başka bir program tarafından kullanılıyordur.</translation>
     </message>
+    <message>
+        <source>Snapshot</source>
+        <translation>Ekrançıktısı</translation>
+    </message>
+    <message>
+        <source>Imagepath</source>
+        <translation>Resim yolu</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>Bu pencereyi gizle</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>Kayıttan önce geri say</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
