@@ -103,6 +103,7 @@
     </message>
     <message>
         <source>No filemanager found.</source>
+        <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
         <translation>未发现文件管理器</translation>
     </message>
     <message>
@@ -147,6 +148,17 @@
         <translation>区域</translation>
     </message>
 </context>
+<context>
+    <name>QvkSnapshot</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>未发现文件管理器</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>请安装一个文件管理器。</translation>
+    </message>
+</context>
 <context>
     <name>QvkSystray</name>
     <message>
@@ -406,10 +418,6 @@
         <source>Gray</source>
         <translation>灰度</translation>
     </message>
-    <message>
-        <source>Send Report</source>
-        <translation>发送报告</translation>
-    </message>
     <message>
         <source>CTRL+SHIFT+F10</source>
         <translation>CTRL+SHIFT+F10</translation>
@@ -522,6 +530,22 @@
         <source>If it shows assigned but does not work, it is being used by another program.</source>
         <translation>如果已指定但是不工作，意味着其它程序已使用</translation>
     </message>
+    <message>
+        <source>Snapshot</source>
+        <translation>截屏</translation>
+    </message>
+    <message>
+        <source>Imagepath</source>
+        <translation>图片路径</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>隐藏窗口</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>开始录制前请等待数秒</translation>
+    </message>
 </context>
 <context>
     <name>license</name>
