@@ -28,15 +28,15 @@
     <name>QvkCiscoFinishDialog</name>
     <message>
         <source>The setup was successful.</source>
-        <translation type="unfinished"/>
+        <translation>設定成功</translation>
     </message>
     <message>
         <source>Close this window and start vokoscreenNG again.</source>
-        <translation type="unfinished"/>
+        <translation>關閉視窗並重新啟動vokoscreenNG</translation>
     </message>
     <message>
         <source>Have fun with vokoscreenNG</source>
-        <translation type="unfinished"/>
+        <translation>祝使用vokoscreenNG愉快</translation>
     </message>
 </context>
 <context>
@@ -103,6 +103,7 @@
     </message>
     <message>
         <source>No filemanager found.</source>
+        <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
         <translation>找不到檔案管理員程式</translation>
     </message>
     <message>
@@ -147,6 +148,17 @@
         <translation>區域</translation>
     </message>
 </context>
+<context>
+    <name>QvkSnapshot</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation>找不到檔案管理員程式</translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation>請安裝檔案管理員程式</translation>
+    </message>
+</context>
 <context>
     <name>QvkSystray</name>
     <message>
@@ -406,10 +418,6 @@
         <source>Gray</source>
         <translation>灰色</translation>
     </message>
-    <message>
-        <source>Send Report</source>
-        <translation>發送報告</translation>
-    </message>
     <message>
         <source>CTRL+SHIFT+F10</source>
         <translation>CTRL+SHIFT+F10</translation>
@@ -488,39 +496,55 @@
     </message>
     <message>
         <source>Automatically</source>
-        <translation type="unfinished"/>
+        <translation>自動</translation>
     </message>
     <message>
         <source>Create images of tabs </source>
-        <translation type="unfinished"/>
+        <translation>創建圖像標籤</translation>
     </message>
     <message>
         <source>License information</source>
-        <translation type="unfinished"/>
+        <translation>認証資訊</translation>
     </message>
     <message>
         <source>ON</source>
-        <translation type="unfinished"/>
+        <translation>開啟</translation>
     </message>
     <message>
         <source>OFF</source>
-        <translation type="unfinished"/>
+        <translation>關閉</translation>
     </message>
     <message>
         <source>Global keyboard shortcuts</source>
-        <translation type="unfinished"/>
+        <translation>全域鍵盤快捷鍵</translation>
     </message>
     <message>
         <source>Assigned shortcut keys.</source>
-        <translation type="unfinished"/>
+        <translation>設定快捷鍵</translation>
     </message>
     <message>
         <source>Keyboard shortcut not assigned or assigned more than once.</source>
-        <translation type="unfinished"/>
+        <translation>快捷鍵尚未設定或已重複設定</translation>
     </message>
     <message>
         <source>If it shows assigned but does not work, it is being used by another program.</source>
-        <translation type="unfinished"/>
+        <translation>若顯示已設定卻沒作用，表示已被其他程式所用</translation>
+    </message>
+    <message>
+        <source>Snapshot</source>
+        <translation>截圖</translation>
+    </message>
+    <message>
+        <source>Imagepath</source>
+        <translation>圖片路徑</translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation>隱藏這個視窗</translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation>開始錄製前等待之秒數</translation>
     </message>
 </context>
 <context>
