@@ -1,5 +1,5 @@
 /* vokoscreenNG - A desktop recorder
- * Copyright (C) 2017-2019 Volker Kohaupt
+ * Copyright (C) 2017-2022 Volker Kohaupt
  * 
  * Author:
  *      Volker Kohaupt <vkohaupt@volkoh.de>
@@ -66,13 +66,13 @@ public:
     QvkWinInfo *vkWinInfo;
     QvkCountdown *vkCountdown;
     QvkRegionChoise *vkRegionChoise;
-    QvkHelp *vkHelp;
     QvkSystray *vkSystray;
     QvkAudioController *vkAudioController;
     QvkSpezialSlider *sliderFrames;
-
     QvkMagnifierController *vkMagnifierController;
     QvkGlobalShortcut *vkGlobalShortcut;
+    bool wantRecording = true;
+    bool isFlatpak = false;
 
 
 private:
@@ -90,6 +90,8 @@ private:
     QvkSpezialSlider *sliderStopRecordingAfterHouers;
     QvkSpezialSlider *sliderStopRecordingAfterMinutes;
     QvkSpezialSlider *sliderStopRecordingAfterSeconds;
+    QvkSpezialSlider *sliderWaitBeforeSnapshot;
+    QvkSpezialSlider *sliderGstDebugLevel;
 
     QvkSettings vkSettings;
 
@@ -135,26 +137,25 @@ private:
     QvkSystrayAlternative *vkSystrayAlternative;
 
     QvkLimitDiskFreeSpace *vkLimitDiskFreeSpace;
-    bool wantRecording = true;
 
     void checkVideoPath();
-
     bool isAudioDeviceSelected();
-
     QString Pipeline_structured_output( QString pipeline );
-
     QSoundEffect *soundEffect;
-
     bool cancel = false;
+    bool is_videoFolderExists_and_haveWritePermission();
+    QPalette appPalette;
+    QString lastButtonPressed = "start";
+
+    bool openh264ProfileTest;
+
+    bool gst_appsrc = false;
 
-    bool have_video_folder_write_permission();
 
 #ifdef Q_OS_WIN
     QvkCiscoOpenh264Controller *vkCiscoOpenh264Controller;
 #endif
 
-    QPalette appPalette;
-
 
 private slots:
     void slot_textToGuiLog( QString value );
@@ -183,6 +184,10 @@ private slots:
     void slot_openh264Reset();
     void slot_vp8Reset();
 
+    void slot_GstreamerDebugLevel( bool );
+    void slot_GstreamerDebugLevelDialog( bool );
+    void slot_GstreamerOpenFolder( bool );
+
     void slot_StartTimer( bool value );
     void slot_startTime();
     void slot_areaSetResolution( QString value );
@@ -190,8 +195,6 @@ private slots:
     void slot_IfStartAudioCodecWidgetsSetEnabled();
     void slot_IfStopAudioCodecWidgetsSetDisabled();
 
-    void slot_sendReport();
-
     void slot_setMaxFPS( int );
 
     void slot_gst_formatVideoAudoicodec_available();
@@ -200,6 +203,8 @@ private slots:
 
     void slot_haveAudioDeviceSelected( bool bo );
 
+    void slot_comboBoxOpenh264Profile( QStringList list );
+
 
 signals:
     void signal_close();
