@@ -1,5 +1,5 @@
 /* vokoscreenNG - A desktop recorder
- * Copyright (C) 2017-2019 Volker Kohaupt
+ * Copyright (C) 2017-2022 Volker Kohaupt
  * 
  * Author:
  *      Volker Kohaupt <vkohaupt@volkoh.de>
@@ -31,16 +31,12 @@
 #include <QPaintEvent>
 #include <QIcon>
 
-#ifdef Q_OS_LINUX
-  #include <QX11Info>
-#endif
-
 QvkRegionChoise::QvkRegionChoise( Ui_formMainWindow *ui_formMainWindow ):handlePressed(NoHandle),
                                    handleUnderMouse(NoHandle),
                                    HandleColorBackground( Qt::lightGray ),
                                    HandleColorBackgroundSize( Qt::lightGray ),
                                    HandleColorByMousePressed( Qt::lightGray ),
-                                   colorSelectedArrow( Qt::green ),
+                                   colorSelectedArrow( QColor( QString ( "#3DAEE9" ) ) ),
                                    framePenWidth(4), // framePenWidth must be an even number
                                    framePenHalf(framePenWidth/2),
                                    radius(20),
@@ -55,13 +51,6 @@ QvkRegionChoise::QvkRegionChoise( Ui_formMainWindow *ui_formMainWindow ):handleP
                                    frame_min_height(200 + framePenWidth),
                                    frameColor(Qt::lightGray)
 {
-#ifdef Q_OS_LINUX
-    if ( QX11Info::isPlatformX11() == true )
-        platform = x11;
-
-    if ( QX11Info::isPlatformX11() == false )
-        platform = wayland;
-#endif
     ui = ui_formMainWindow;
 
     setWindowTitle( QString( tr( "Area") ) );
@@ -70,17 +59,18 @@ QvkRegionChoise::QvkRegionChoise( Ui_formMainWindow *ui_formMainWindow ):handleP
     icon.addFile( QString::fromUtf8( ":/pictures/logo/logo.png" ), QSize(), QIcon::Normal, QIcon::Off );
     setWindowIcon( icon );
 
-    // Hint: Qt::WindowStaysOnTopHint is only for X11 and Windows on WayLand not do it
-    setWindowFlags( Qt::FramelessWindowHint | Qt::WindowStaysOnTopHint | Qt::ToolTip ); // With Qt::ToolTip no keyboard;
-    setAttribute( Qt::WA_TranslucentBackground, true);
+    // QTooltip have no keyboard input focus, we must set the window active, see QvkRegionChoise::mouseReleaseEvent()
+    setWindowFlags( Qt::FramelessWindowHint | Qt::WindowStaysOnTopHint | Qt::ToolTip );
+    setAttribute( Qt::WA_TranslucentBackground, true );
     setMouseTracking( true );
-    setFrameColor( Qt::darkGreen );
+    setFrameColor( QString( "#3DAEE9" ) );
     hide();
 }
 
 
 void QvkRegionChoise::slot_init()
 {
+#ifdef Q_OS_LINUX
     if ( ui->comboBoxScreencastScreenArea->currentIndex() > -1 )
     {
         int index = ui->comboBoxScreencastScreenArea->currentIndex();
@@ -92,8 +82,30 @@ void QvkRegionChoise::slot_init()
         screenHeight = screen->size().height();
         move( screen->geometry().x(), screen->geometry().y() );
     }
-}
+#endif
 
+#ifdef Q_OS_WIN
+    // Für das anzeigen der Bereichsanzeige auf dem Bildschirm wird der Index aus einer unsortierten Liste benötigt.
+    if ( ui->comboBoxScreencastScreenArea->currentIndex() > -1 )
+    {
+        int index = 0;
+        QString nameDisplay = ui->comboBoxScreencastScreenArea->currentText().section( ":", 0, 0 ).trimmed();
+        QList<QScreen *> screenList = QGuiApplication::screens(); // unsortiert
+        for ( int i=0; i < screenList.count(); i++ ) {
+            QString nameList = screenList.at(i)->name().remove( "." ).remove( "\\" ) ;
+            if ( nameDisplay == nameList )
+            {
+                index = i;
+            }
+        }
+        screen = screenList.at( index );
+        resize( screen->size().width(), screen->size().height() );
+        screenWidth = screen->size().width();
+        screenHeight = screen->size().height();
+        move( screen->geometry().x(), screen->geometry().y() );
+    }
+#endif
+}
 
 QvkRegionChoise::~QvkRegionChoise()
 {
@@ -268,25 +280,8 @@ void QvkRegionChoise::mousePressEvent(QMouseEvent *event)
     old_Frame_X2 = frame_X + frame_Width;
     old_Frame_Y2 = frame_Y + frame_height;
 
-#ifdef Q_OS_WIN
     repaint();
     update();
-#endif
-
-#ifdef Q_OS_LINUX
-    if ( platform == wayland )
-    {
-      clearMask();
-      update();
-    }
-
-    if ( platform == x11 )
-    {
-      repaint();
-      update();
-    }
-#endif
-
 }
 
 
@@ -299,6 +294,9 @@ void QvkRegionChoise::mouseReleaseEvent( QMouseEvent * event )
 
   handlePressed = NoHandle;
 
+  // QTooltip have no keyboard input focus, we must set the window aktiv.
+  activateWindow();
+
   update();
 }
 
@@ -930,35 +928,8 @@ void QvkRegionChoise::mouseMoveEvent( QMouseEvent *event )
                          }
     } // end switch
 
-#ifdef Q_OS_LINUX
-    if ( handlePressed != NoHandle )
-    {
-        if ( platform == wayland )
-        {
-            clearMask();
-            update();
-        }
-
-        if ( platform == x11 )
-        {
-            if ( QX11Info::isCompositingManagerRunning() == true )
-            {
-                repaint();
-                update();
-            }
-            else
-            {
-                repaint();
-                update();
-            }
-        }
-    }
-#endif
-
-#ifdef Q_OS_WIN
     repaint();
     update();
-#endif
 
     if ( handlePressed != NoHandle )
         return;
@@ -1116,13 +1087,13 @@ void QvkRegionChoise::drawFrame(QPainter &painter)
 }
 
 
-void QvkRegionChoise::setFrameColor( Qt::GlobalColor color )
+void QvkRegionChoise::setFrameColor( QColor color )
 {
     frameColor = color;
 }
 
 
-Qt::GlobalColor QvkRegionChoise::getFrameColor()
+QColor QvkRegionChoise::getFrameColor()
 {
     return frameColor;
 }
