@@ -1,6 +1,6 @@
 /* vokoscreenNG - A desktop recorder
- * Copyright (C) 2017-2019 Volker Kohaupt
- * 
+ * Copyright (C) 2017-2022 Volker Kohaupt
+ *
  * Author:
  *      Volker Kohaupt <vkohaupt@volkoh.de>
  *
@@ -26,14 +26,19 @@
 #include <QScreen>
 #include <QGuiApplication>
 #include <QDebug>
-
 #include <QApplication>
+#include <QToolButton>
 
-QvkScreenManager::QvkScreenManager()
+QvkScreenManager::QvkScreenManager( QMainWindow *parent )
 {
-    connect( qApp, SIGNAL( screenAdded( QScreen* ) ),   this, SLOT( slot_screen_count_changed() ) );
-    connect( qApp, SIGNAL( screenRemoved( QScreen* ) ), this, SLOT( slot_screen_count_changed() ) );
+    connect( qApp, SIGNAL( screenAdded( QScreen* ) ),          this, SLOT( slot_screen_count_changed() ) );
+    connect( qApp, SIGNAL( screenRemoved( QScreen* ) ),        this, SLOT( slot_screen_count_changed() ) );
     connect( qApp, SIGNAL( primaryScreenChanged( QScreen* ) ), this, SLOT( slot_screen_count_changed() ) );
+
+    QToolButton *toolButton = parent->findChild<QToolButton *>("toolButton_screen_name");
+    if ( toolButton != NULL ) {
+        connect( toolButton, SIGNAL( toggled( bool ) ), this, SLOT( slot_toolButton_toggled( bool ) ) );
+    }
 }
 
 
@@ -46,6 +51,7 @@ void QvkScreenManager::init()
 QvkScreenManager::~QvkScreenManager()
 {}
 
+
 void QvkScreenManager::slot_screen_count_changed()
 {
     QList<QScreen *> screen = QGuiApplication::screens();
@@ -73,11 +79,11 @@ void QvkScreenManager::slot_screen_count_changed()
             QString Y = QString::number( static_cast<int>( screen.at(i)->geometry().top() * screen.at(i)->devicePixelRatio() ) );
             QString Width = QString::number( static_cast<int>( screen.at(i)->geometry().width() * screen.at(i)->devicePixelRatio() ) );
             QString Height = QString::number( static_cast<int>( screen.at(i)->geometry().height() * screen.at(i)->devicePixelRatio() ) );
-            QString stringText = screen.at(i)->name() + " " + ":  " + Width + " x " + Height;
+            QString stringText = screen.at(i)->name().remove( "." ).remove( '\\' ) + " " + ":  " + Width + " x " + Height;
             QString stringData = "x=" + X + " " +
-                                 "y=" + Y + " " +
-                                 "with=" + Width + " " +
-                                 "height=" + Height;
+                    "y=" + Y + " " +
+                    "with=" + Width + " " +
+                    "height=" + Height;
 
             disconnect( screen.at(i), nullptr, nullptr, nullptr );
             connect( screen.at(i), SIGNAL( geometryChanged( const QRect ) ), this, SLOT( slot_geometryChanged( const QRect ) ) );
@@ -87,9 +93,40 @@ void QvkScreenManager::slot_screen_count_changed()
     }
 }
 
+
 void QvkScreenManager::slot_geometryChanged( const QRect &rect )
 {
     Q_UNUSED(rect);
     slot_screen_count_changed();
 }
 
+
+void QvkScreenManager::slot_toolButton_toggled( bool checked )
+{
+    QList<QScreen *> screenList = QGuiApplication::screens();
+
+    if ( checked == true ) {
+        labelList.clear();
+        for ( int i = 0; i < screenList.count(); i++ ) {
+            QLabel *label = new QLabel;
+            label->setWindowFlags( Qt::FramelessWindowHint | Qt::WindowStaysOnTopHint | Qt::ToolTip );
+            label->resize( 400, 200 );
+            label->move( screenList.at(i)->geometry().x(), screenList.at(i)->geometry().y() );
+
+            QFont font;
+            font.setPixelSize( 50 );
+            label->setFont( font );
+            label->setStyleSheet( "QLabel { background-color : orange; color : black; }" );
+
+            label->setAlignment( Qt::AlignCenter );
+            label->setText( screenList.at(i)->name().remove( "." ).remove( '\\' ) );
+            label->show();
+            labelList << label;
+        }
+    } else {
+        for ( int i = 0; i < labelList.count(); i++ ) {
+            labelList.at(i)->close();
+            labelList.at(i)->deleteLater();
+        }
+    }
+}
