@@ -1,5 +1,5 @@
 /* vokoscreenNG - A desktop recorder
- * Copyright (C) 2017-2019 Volker Kohaupt
+ * Copyright (C) 2017-2022 Volker Kohaupt
  * 
  * Author:
  *      Volker Kohaupt <vkohaupt@volkoh.de>
@@ -87,6 +87,10 @@ void QvkSettings::readAll( Ui_formMainWindow *ui_mainwindow, QMainWindow *parent
                 QString valueText = settings.value( listComboBoxShortcut.at(i)->objectName(), "F6" ).toString();
                 listComboBoxShortcut.at(i)->setCurrentText( valueText );
             }
+            if ( listComboBoxShortcut.at(i)->objectName() == "comboBox_shortcut_snapshot" ) {
+                QString valueText = settings.value( listComboBoxShortcut.at(i)->objectName(), "F5" ).toString();
+                listComboBoxShortcut.at(i)->setCurrentText( valueText );
+            }
         }
     }
 
@@ -240,6 +244,18 @@ void QvkSettings::readAll( Ui_formMainWindow *ui_mainwindow, QMainWindow *parent
             continue;
         }
 
+        if ( ( listCheckBox.at(i)->objectName().contains( "checkBoxSnapshotShowBallonInSystray" ) ) and
+             ( settings.value( listCheckBox.at(i)->objectName(), true ).toBool() == true ) )
+        {
+            listCheckBox.at(i)->click();
+            continue;
+        }
+
+        if ( ( listCheckBox.at(i)->objectName().contains( "checkBoxGstreamerDebugLevel" ) ) and
+             ( settings.value( listCheckBox.at(i)->objectName(), false ).toBool() == true ) )
+        {
+            continue;
+        }
 
         //
         if ( listCheckBox.at(i)->objectName().contains( "checkBox_shortcut" ) and
@@ -333,6 +349,28 @@ void QvkSettings::readAll( Ui_formMainWindow *ui_mainwindow, QMainWindow *parent
              }
         }
 
+        // Snapshot
+        if ( listCheckBox.at(i)->objectName() == "checkBox_shortcut_snapshot_strg" ) {
+             if ( settings.value( listCheckBox.at(i)->objectName(), true ).toBool() == true ) {
+                 listCheckBox.at(i)->setChecked( true );
+                 continue;
+             }
+        }
+        if ( listCheckBox.at(i)->objectName() == "checkBox_shortcut_snapshot_shift" ) {
+             if ( settings.value( listCheckBox.at(i)->objectName(), true ).toBool() == true ) {
+                 listCheckBox.at(i)->setChecked( true );
+                 continue;
+             }
+        }
+
+
+        if ( ( listCheckBox.at(i)->objectName().contains( "checkBoxSnapshotHideBeforeRecording" ) ) and
+             ( settings.value( listCheckBox.at(i)->objectName(), true ).toBool() == true ) )
+        {
+            listCheckBox.at(i)->click();
+            continue;
+        }
+
         // We found a setting, then we want set or not.
         if ( settings.value( listCheckBox.at(i)->objectName(), false ).toBool() == true )
         {
@@ -348,6 +386,11 @@ void QvkSettings::readAll( Ui_formMainWindow *ui_mainwindow, QMainWindow *parent
             continue;
         }
 
+        if ( listSlider.at(i)->objectName() == "sliderGstDebugLevel" )
+        {
+            continue;
+        }
+
         QVariant variant = settings.value( listSlider.at(i)->objectName() );
         if ( variant.isValid() )
         {
@@ -373,18 +416,37 @@ void QvkSettings::readAll( Ui_formMainWindow *ui_mainwindow, QMainWindow *parent
     for ( int i = 0; i < listTabWidget.count(); i++ )
     {
         listTabWidget.at(i)->setCurrentIndex( 0 );
+
+        QvkSettings vkSettingsGstDebug;
+        QFileInfo fileInfo( vkSettingsGstDebug.getFileName() );
+        QString pathAndFilename = fileInfo.absoluteFilePath();
+        QSettings setingsGstDebug( pathAndFilename, QSettings::IniFormat );
+        bool bo = setingsGstDebug.value( "checkBoxGstreamerDebugLevel" ).toBool();
+        if ( bo == true ) {
+            ui_mainwindow->tabWidgetScreencast->setCurrentIndex( 3 );
+        }
+
     }
 
     QList<QToolButton *> listToolButton = ui_mainwindow->centralWidget->findChildren<QToolButton *>();
     for ( int i = 0; i < listToolButton.count(); i++ )
     {
-        if ( listToolButton.at(i)->objectName().contains( "toolButtonMute" ) )
-        {
+        if ( listToolButton.at(i)->objectName().contains( "toolButtonMute" ) ) {
             QString value = settings.value( listToolButton.at(i)->objectName() ).toString();
-            if ( value == "audio-volume-muted")
-            {
+            if ( value == "audio-volume-muted") {
+                listToolButton.at(i)->click();
+            }
+        }
+
+        if ( listToolButton.at(i)->objectName().contains( "toolButton_camera_view" ) ) {
+            if ( settings.value( listToolButton.at(i)->objectName() ).toBool() == true ) {
+                listToolButton.at(i)->click();
+            }
+        }
+
+        if ( listToolButton.at(i)->objectName().contains( "toolButton_magnifier" ) ) {
+            if ( settings.value( listToolButton.at(i)->objectName() ).toBool() == true ) {
                 listToolButton.at(i)->click();
-                break;
             }
         }
     }
@@ -492,6 +554,14 @@ void QvkSettings::saveAll(Ui_formMainWindow *ui_mainwindow , QMainWindow *parent
                 settings.setValue( listToolButton.at(i)->objectName(), "audio-volume-high" );
             }
         }
+
+        if ( listToolButton.at(i)->objectName().contains( "toolButton_camera_view" ) ) {
+                settings.setValue( listToolButton.at(i)->objectName(), listToolButton.at(i)->isChecked() );
+        }
+
+        if ( listToolButton.at(i)->objectName().contains( "toolButton_magnifier" ) ) {
+                settings.setValue( listToolButton.at(i)->objectName(), listToolButton.at(i)->isChecked() );
+        }
     }
 
     QList<QvkSpezialCheckbox *> listSpezialCheckbox = ui_mainwindow->centralWidget->findChildren<QvkSpezialCheckbox *>();
