@@ -1,5 +1,5 @@
 ﻿/* vokoscreenNG
- * Copyright (C) 2017-2021 Volker Kohaupt
+ * Copyright (C) 2017-2022 Volker Kohaupt
  *
  * Author:
  *      Volker Kohaupt <vkohaupt@volkoh.de>
@@ -67,7 +67,7 @@ QvkAnimateWindow::QvkAnimateWindow( QWidget *parent,
     opacity = valueOpacity / 100;
     color = valueColor;
 
-    QTimer::singleShot( showTime, this, SLOT( close() ) );
+    QTimer::singleShot( showTime, Qt::PreciseTimer, this, SLOT( close() ) );
     global::showclickCounter++;
     show();
 }
