@@ -1,5 +1,5 @@
 /* vokoscreenNG - A desktop recorder
- * Copyright (C) 2017-2019 Volker Kohaupt
+ * Copyright (C) 2017-2022 Volker Kohaupt
  * 
  * Author:
  *      Volker Kohaupt <vkohaupt@volkoh.de>
@@ -92,6 +92,11 @@ void QvkSystray::init()
     haloAction->setData( "Halo" );
     haloAction->setCheckable( true );
 
+    snapshotAction = new QAction( this );
+    snapshotAction->setIcon( QIcon( ":pictures/systray/snapshot.png" ) );
+    snapshotAction->setText( "Snapshot" );
+    snapshotAction->setData( "Snapshot" );
+
     exitAction = new QAction( this );
     exitAction->setIcon( QIcon( ":pictures/systray/exit.png" ) );
     exitAction->setText( tr( "Exit" ) );
@@ -152,6 +157,8 @@ void QvkSystray::init()
         }
     }
 
+    connect( snapshotAction, SIGNAL( triggered( bool ) ), ui->pushButtonScreencastSnapshot, SLOT( click() ) );
+
     menu = new QMenu();
     menu->addAction( titleAction );
     menu->addSeparator();
@@ -164,6 +171,7 @@ void QvkSystray::init()
     menu->addAction( magnifierAction );
     menu->addAction( showclickAction );
     menu->addAction( haloAction );
+    menu->addAction( snapshotAction );
     menu->addSeparator();
     menu->addAction( exitAction );
 
@@ -180,7 +188,6 @@ void QvkSystray::init()
     if ( ui->checkBoxCameraOnOff->isEnabled() == false ){
         cameraAction->setEnabled( false );
     }
-
 }
 
 
@@ -213,7 +220,7 @@ void QvkSystray::slot_hide()
     emit signal_SystemtrayIsClose();
 }
 
-// This slot need in Main GUI
+
 void QvkSystray::slot_closeSystray()
 {
     hide();
@@ -240,10 +247,11 @@ void QvkSystray::slot_setPauseIcon( bool )
 
 void QvkSystray::slot_currentIndexChanged( int index )
 {
-    if ( index > -1 )
+    if ( index > -1 ) {
         cameraAction->setEnabled( true );
-    else
+    } else {
         cameraAction->setEnabled( false );
+    }
 }
 
 
@@ -314,4 +322,11 @@ void QvkSystray::slot_shortcutSystray( QString device, QString shortcut )
         }
     }
 
+    if ( device == "snapshot" ){
+        snapshotAction->setShortcutVisibleInContextMenu( true );
+        snapshotAction->setShortcut( QKeySequence::fromString( shortcut ) );
+        if ( shortcut == "None" ){
+            snapshotAction->setShortcutVisibleInContextMenu( false );
+        }
+    }
 }
