@@ -105,6 +105,7 @@
     </message>
     <message>
         <source>No filemanager found.</source>
+        <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -149,6 +150,17 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>QvkSnapshot</name>
+    <message>
+        <source>No filemanager found.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Please install a filemanager.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>QvkSystray</name>
     <message>
@@ -408,10 +420,6 @@
         <source>Gray</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Send Report</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>CTRL+SHIFT+F10</source>
         <translation type="unfinished"></translation>
@@ -524,6 +532,22 @@
         <source>If it shows assigned but does not work, it is being used by another program.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Snapshot</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Imagepath</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hide this window</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Seconds wait before recording</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>license</name>
