@@ -6,7 +6,6 @@
 #include <QStandardPaths>
 #include <QDateTime>
 #include <QThread>
-#include <QMimeDatabase>
 #include <QMessageBox>
 #include <QDebug>
 #include <QStyleFactory>
@@ -105,7 +104,7 @@ void QvkMainWindow_wl::set_CornerWidget()
     list << ui->tabWidgetScreencast;
     list << ui->tabWidgetLog;
 
-    QPixmap pixmap( ":/pictures/wayland.png" );
+    QPixmap pixmap( ":/pictures/cornerWidget/wayland.png" );
     pixmap = pixmap.scaled( QSize( 48, 48 ), Qt::IgnoreAspectRatio, Qt::SmoothTransformation );
 
     for ( int i = 0; i < list.count(); i++ )
@@ -341,12 +340,14 @@ void QvkMainWindow_wl::slot_frames_Reset()
 
 void QvkMainWindow_wl::messageBox( QString value )
 {
+    QPixmap pixmap( ":/pictures/status/warning.png" );
+    pixmap = pixmap.scaled( 64, 64, Qt::IgnoreAspectRatio, Qt::SmoothTransformation );
     QMessageBox *messageBox = new QMessageBox();
     QIcon icon( QString::fromUtf8( ":/pictures/logo/logo.png" ) );
     messageBox->setWindowIcon( icon );
     messageBox->setWindowTitle( global::name + " " + global::version );
-    messageBox->setIcon( QMessageBox::Critical );
-    messageBox->setText( ( "Wayland desktop session detected" ) );
+    messageBox->setIconPixmap( pixmap );
+    messageBox->setText( "Wayland desktop session detected" );
     messageBox->setInformativeText( ( "Please install the package\n" + value ) );
     messageBox->exec();
     exit(0);
