@@ -1,5 +1,5 @@
 /* vokoscreenNG - A desktop recorder
- * Copyright (C) 2017-2019 Volker Kohaupt
+ * Copyright (C) 2017-2022 Volker Kohaupt
  * 
  * Author:
  *      Volker Kohaupt <vkohaupt@volkoh.de>
@@ -26,7 +26,6 @@
 #include <QDebug>
 
 #ifdef Q_OS_LINUX
-#include <QX11Info>
 #include <X11/Xutil.h>
 #endif
 
@@ -75,7 +74,7 @@ void QvkWinInfo::paintEvent( QPaintEvent *event )
     pixmap.fill( Qt::transparent );
     QPainter painter;
     painter.begin( &pixmap );
-    painter.setPen( QPen( Qt::blue, 4 ) );
+    painter.setPen( QPen( QColor( QString( "#3daee9" ) ), 4 ) );
     painter.drawLine( 50/2, 0, 50/2, 15 );
     painter.drawLine( 50/2, 50/2+10, 50/2, 50 );
     painter.drawLine( 0, 50/2, 50/2-10, 50/2 );
@@ -99,51 +98,60 @@ void QvkWinInfo::slot_mousePosition()
 
 
 #ifdef Q_OS_LINUX
-static WindowList getWindow( Atom prop )
+static listWinId getWindow( Atom prop )
 {
-    WindowList res;
+    listWinId listWId;
     Atom type = 0;
     int format = 0;
     uchar* data = Q_NULLPTR;
-    ulong count, after;
-    Display* display = QX11Info::display();
-    Window window = QX11Info::appRootWindow();
+    ulong count;
+    ulong after;
+
+    Display *display = XOpenDisplay( NULL );
+    Window window = XDefaultRootWindow( display) ;
     if ( XGetWindowProperty( display, window, prop, 0, 1024 * sizeof(Window) / 4, False, AnyPropertyType,
                              &type, &format, &count, &after, &data ) == Success )
     {
         Window* list = reinterpret_cast<Window*>( data ) ;
         for ( uint i = 0; i < count; ++i )
-            res += list[i];
-        if (data)
+            listWId += list[i];
+        if ( data )
             XFree( data );
     }
-    return res;
+
+    XCloseDisplay( display );
+
+    return listWId;
 }
 
 
 WId QvkWinInfo::activeWindow()
 {
     static Atom net_active = 0;
-    if ( !net_active )
-        net_active = XInternAtom( QX11Info::display(), "_NET_ACTIVE_WINDOW", True );
+    if ( !net_active ) {
+        Display *display = XOpenDisplay( NULL );
+        net_active = XInternAtom( display, "_NET_ACTIVE_WINDOW", True );
+        XCloseDisplay( display );
+    }
 
     return getWindow( net_active ).value(0);
 }
 
 
-QRectF QvkWinInfo::windowGeometryWithoutFrame( WId child)
+QRectF QvkWinInfo::windowGeometryWithoutFrame( WId child )
 {
     int x, y;
     Window root;
     uint w, h, border, depth;
 
-    XGetGeometry( QX11Info::display(), child, &root, &x, &y, &w, &h, &border, &depth );
+    Display *display = XOpenDisplay( NULL );
+    XGetGeometry( display, child, &root, &x, &y, &w, &h, &border, &depth );
 
     Window parent;
     Window* children;
     unsigned int nchildren;
 
-    if( XQueryTree( QX11Info::display(), child, &root, &parent, &children, &nchildren ) != 0 )
+    if( XQueryTree( display, child, &root, &parent, &children, &nchildren ) != 0 )
     {
         if( children != nullptr )
         {
@@ -152,14 +160,16 @@ QRectF QvkWinInfo::windowGeometryWithoutFrame( WId child)
 
         int newx, newy;
         Window dummy;
-
-        if( XTranslateCoordinates( QX11Info::display(), parent, QX11Info::appRootWindow(), x, y, &newx, &newy, &dummy ))
+        Window window = root;
+        if( XTranslateCoordinates( display, parent, window, x, y, &newx, &newy, &dummy ) )
         {
             x = newx;
             y = newy;
         }
     }
 
+    XCloseDisplay( display );
+
     QRectF rect( x, y, w, h );
 
     return rect;
